angular.module('app.directives', [])

.directive('selectOnClick', function () {
  return {
    restrict: 'A',
    link: function (scope, element, attrs) {
      element.on('click', function () {
        try {
          this.setSelectionRange(0, 9999); // no IOS
        } catch (e) {
          this.select(true);
        }
      });
    }
  };
})

.directive('clickForOptions', ['$ionicGesture', function($ionicGesture) {
    return {
        restrict: 'A',
        link: function (scope, element, attrs) {
            $ionicGesture.on('tap', function(e){

                // Grab the content
                var content = element[0].querySelector('.item-content');

                // Grab the buttons and their width
                var buttons = element[0].querySelector('.item-options');

                if (!buttons) {
                    // console.log('There are no option buttons');
                    return;
                }
                var buttonsWidth = buttons.offsetWidth;

                ionic.requestAnimationFrame(function() {
                    content.style[ionic.CSS.TRANSITION] = 'all ease-out .25s';

                    if (!buttons.classList.contains('invisible')) {
                        // console.log('close');
                        content.style[ionic.CSS.TRANSFORM] = '';
                        setTimeout(function() {
                            buttons.classList.add('invisible');
                        }, 250);
                    } else {
                        buttons.classList.remove('invisible');
                        content.style[ionic.CSS.TRANSFORM] = 'translate3d(-' + buttonsWidth + 'px, 0, 0)';
                    }
                });

            }, element);
        }
    };
}])
.directive('fichaAnotacoesHistoricoItem', [function () {
    return {
        restrict: 'E',
        replace:true,
         scope:{
             servico: '@',
             quantidade: '@'
         },
        template: '<div style="padding-left:0px;" class="row"><div style="padding-left:0px;" class="col">{{servico}} - {{quantidade}}</div></div>'
    };
}])

.directive('fichaAnotacoesHistoricoMedico', [function () {
    return {
        restrict: 'E',
        replace:true,
         scope:{
             medico: '@',
             titulo:'@'
         },
        template: '<a href="#" class="item item-icon-left"><i class="icon ion-medkit"></i> <span class="negrito">{{titulo}}</span> {{medico}}</a>'
    };
}])

.directive('fichaAnotacoesHistoricoData', [function () {
    return {
        restrict: 'E',
        replace:true,
         scope:{
             data: '@'
         },
        template: '<a href="#" class="item item-icon-left"><i class="icon ion-calendar"></i>\
         <span class="item-text-center"><span class="negrito">{{"APP_CLIENT_HISTORY_CLIENT_DATE_LABEL"|translate}}</span> {{data | date:"shortDate"}}</span></a>'
    };
}])
.directive('fichaAnotacoesHistoricoServicos', [function () {
    return {
        restrict: 'E',
        replace:true,
        templateUrl: 'templates/contributor/historicoAnotacoes/diretivas/servicos.html'
    };
}])
.directive('fichaAnotacoesHistoricoCliente', [function () {
    return {
        restrict: 'E',
        replace:true,
        scope:{
          nome :'@',
          cpf :'@',
          codigo: '@'
        },
        template: '<div><span class="negrito">{{"APP_CLIENT_HISTORY_CLIENT_NAME_LABEL"|translate}}</span> {{nome}}\
         | <span class="negrito"{{"APP_CLIENT_HISTORY_CLIENT_CPF_LABEL" | translate}}</span> {{cpf}}\
         | <span class="negrito">{{"APP_CLIENT_HISTORY_CLIENT_INNER_CODE_LABEL" | translate}}</span> {{codigo}}</div>'
    };
}])
.directive('historicoBuscarCliente', [function () {
    return {
        restrict: 'E',
        replace:true,
        scope:true,
        controller: 'contributor.historico.BuscarClienteCtrl',
        templateUrl: 'templates/contributor/historico/diretivas/buscarCliente.html'
    };
}])

.directive('salaoSobreDescricao', [function () {
    return {
        restrict: 'E',
        replace:true,
        transclude:true,
        scope:{},
        templateUrl: 'templates/directive/SalaoSobreDescricao.html'
    };
}])

.directive('a', function () {
    return {
        restrict: 'E',
        link: function (scope, element, attrs) {
            if ( !attrs.href ){
                return;
            }
            var externalRe = new RegExp("^(http|https)://");
            var url = attrs.href;

            if(externalRe.test(url)) {
                element.on('click',function(e){
                    e.preventDefault();
                    if(attrs.ngClick){
                        scope.$eval(attrs.ngClick);
                    }
                    window.open(encodeURI(url), '_system');
                });
            }
        }
    };
})

.directive('languageBox', ['$state', function ($state) {
    return {
        restrict: 'E',
        // replace:true,
        template:
          '<div class="language-box {{$state.$current.name}}" ng-click="openModal()"> \
            <img ng-src="{{IMG}}/{{DEALER.icons.language.plus||\'plus\'}}.png" height="20">\
            <img class="flag" ng-src="{{IMG}}/{{currentLanguage}}.png"> \
          </div>',
        // scope: {
        //   $state: $state
        // }
        controller: ['$scope', '$ionicModal', function ($scope, $ionicModal) {
          $ionicModal.fromTemplateUrl('templates/directive/language-box-modal.html', {
            scope: $scope,
            animation: 'slide-in-up'
          }).then(function(modal) {
            $scope.modal = modal;
                });
          $scope.openModal = function() {
            $scope.modal.show();
          };
          $scope.closeModal = function() {
            $scope.modal.hide();
          };
          // Cleanup the modal when we're done with it!
          $scope.$on('$destroy', function() {
            $scope.modal.remove();
          });
          // Execute action on hide modal
          $scope.$on('modal.hidden', function() {
            // Execute action
          });
          // Execute action on remove modal
          $scope.$on('modal.removed', function() {
            // Execute action
          });
          $scope.availableLanguages = [
            ['pt-br', 'Português (Brasil)'],
            ['en-us', 'English (USA)'],
            ['es-es', 'Español'],
          ]
        }]
    };
}])


.directive('fixed2', ['$timeout', '$filter', function ($timeout, $filter) {
  return {
    restrict: 'A',
    scope: {
      ngModel: '=',
    },
    compile : function compile(tElement, tAttributes) {
        return {
            pre : function preLink(scope, element, attributes) {
              attributes.$set('type', 'text');

              scope.ngModel = Number(scope.ngModel).toFixed(2);
              // scope.ngModel = $filter('currency')((''+scope.ngModel).replace(',', '.'), '');

              element.bind('focus', function () {
                attributes.$set('type', 'number');
                $timeout(function () {
                scope.ngModel = Number(scope.ngModel.replace(',', '.'));
                  // scope.ngModel = Number(scope.ngModel).toFixed(2);
                  // scope.ngModel = $filter('currency')(scope.ngModel, '');
                });
              });
              element.bind('blur', function () {
                attributes.$set('type', 'text');
                $timeout(function () {
                  scope.ngModel = Number(scope.ngModel).toFixed(2);
                  // scope.ngModel = $filter('currency')(scope.ngModel, '');
                });
              });
            },
        };
    }
  };
}])

.directive('fullName', function () {
   return {
      require: 'ngModel',
      link: function(scope, elem, attr, ngModel) {
        //For DOM -> model validation
        ngModel.$parsers.unshift(function (value) {
          // debugger;
          var valid = ~value.indexOf(' ');
          ngModel.$setValidity('fullName', valid);
          return valid ? value : undefined;
        });

        //For model -> DOM validation
        ngModel.$formatters.unshift(function (value) {
          ngModel.$setValidity('fullName', false);
          return value;
        });
      }
   };
})

;
